# -*- coding: utf-8 -*-

from kkconst import BaseConst, ConstIntField


class BaseStatusCode(BaseConst):
    class Meta:
        allow_duplicated_value = False  # status_code should be no duplicated value


class StatusCodeField(ConstIntField):
    def __init__(self, status_code, message='', description=''):
        ConstIntField.__init__(status_code, verbose_name=message, description=description)
        self.message = message


class UserStatusCode(BaseStatusCode):
    """ 摄影师／用户相关错误码 400x & 401x """
    LENSMAN_NOT_FOUND = StatusCodeField(4000, u'Lensman Not Found', description=u'摄影师不存在')
    LENSMAN_PASSWORD_ERROR = StatusCodeField(4001, u'Lensman Password Error', description=u'摄影师密码错误')
    USERNAME_HAS_REGISTERED = StatusCodeField(4010, u'Username Has Registered', description=u'用户名已注册')
    USER_NOT_FOUND = StatusCodeField(4011, u'User Not Found', description=u'用户不存在')
    USER_PASSWORD_ERROR = StatusCodeField(4012, u'User Password Error', description=u'用户密码错误')


class PhotoStatusCode(BaseStatusCode):
    """ 照片相关错误码 403x """
    PARAMS_ERROR = StatusCodeField(4039, u'Params Error', description=u'参数错误')


class GroupStatusCode(BaseStatusCode):
    """ 群组相关错误码 402x """
    GROUP_NOT_FOUND = StatusCodeField(4020, u'Group Not Found', description=u'群组不存在')
    GROUP_HAS_LOCKED = StatusCodeField(4021, u'Group Has Locked', description=u'群组已锁定')
    NOT_GROUP_ADMIN = StatusCodeField(4022, u'Not Group Admin', description=u'非群组管理员')
    NO_UPDATE_PERMISSION = StatusCodeField(40220, u'No Update Permission', description=u'没有更新权限')
    NO_LOCK_PERMISSION = StatusCodeField(40221, u'No Lock Permission', description=u'没有锁定权限')
    NO_UNLOCK_PERMISSION = StatusCodeField(40222, u'No Unlock Permission', description=u'没有解锁权限')
    NO_REMOVE_PERMISSION = StatusCodeField(40223, u'No Remove Permission', description=u'没有移除权限')
    NO_PASS_PERMISSION = StatusCodeField(40224, u'No Pass Permission', description=u'没有通过权限')
    NO_REFUSE_PERMISSION = StatusCodeField(40225, u'No Refuse Permission', description=u'没有拒绝权限')
    DUPLICATE_JOIN_REQUEST = StatusCodeField(4027, u'Duplicate Join Request', description=u'重复加群申请')
    JOIN_REQUEST_NOT_FOUND = StatusCodeField(4028, u'Join Request Not Found', description=u'加群申请不存在')
    GROUP_USER_NOT_FOUND = StatusCodeField(4029, u'Group User Not Found', description=u'该用户不在群组')


class GroupPhotoStatusCode(BaseStatusCode):
    """ 飞图相关错误码 403x """
    GROUP_PHOTO_NOT_FOUND = StatusCodeField(4030, u'Group Photo Not Found', description=u'飞图不存在')


class OrderStatusCode(BaseStatusCode):
    """ 订单／支付相关错误码 404x """
    WX_UNIFIED_ORDER_FAIL = StatusCodeField(4040, u'WX Unified Order Fail', description=u'微信统一下单失败')


class MessageStatusCode(BaseStatusCode):
    """ 消息相关错误码 409x """
    MESSAGE_NOT_FOUND = StatusCodeField(4091, u'Message Not Found', description=u'消息不存在')
